@@ -9,7 +9,7 @@ use FFI::Platypus::Memory qw( malloc free );
 use Carp qw( croak carp );
 
 # ABSTRACT: Tiny C Compiler for FFI
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 
 sub _dlext ()
@@ -149,20 +149,7 @@ sub add_symbol
 {
   my($self, $name, $ptr) = @_;
   my $r;
-  if(ref($ptr) && eval { $ptr->isa('FFI::Raw::Callback') })
-  {
-    require FFI::Raw;
-    my($lib) = $ffi->lib;
-    my $add_symbol = FFI::Raw->new($lib, 'tcc_add_symbol',
-      FFI::Raw::int(),
-      FFI::Raw::ptr(), FFI::Raw::str(), FFI::Raw::ptr(),
-    );
-    $r = $add_symbol->call($self->{handle}, $name, $ptr);
-  }
-  else
-  {
-    $r = _add_symbol($self, $name, $ptr);
-  }
+  $r = _add_symbol($self, $name, $ptr);
   die FFI::TinyCC::Exception->new($self) if $r == -1;
   $self;
 }
@@ -280,22 +267,6 @@ sub get_symbol
 
 _method output_file => qw( string );
 
-
-# this variable will too be removed once this module
-# is ported to FFI::Platypus, so do not depeend on it!
-our $_get_ffi_raw_deprecation = 1;
-
-sub get_ffi_raw
-{
-  carp "FFI::TinyCC->get_ffi_raw is deprecated" if $_get_ffi_raw_deprecation;
-  my($self, $symbol, @types) = @_;
-  croak "you must at least specify a return type" unless @types > 0;
-  my $ptr = $self->get_symbol($symbol);
-  croak "$symbol not found" unless $ptr;
-  require FFI::Raw;
-  FFI::Raw->new_from_ptr($self->get_symbol($symbol), @types);
-}
-
 package
   FFI::TinyCC::Exception;
 
@@ -365,7 +336,7 @@ FFI::TinyCC - Tiny C Compiler for FFI
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -470,9 +441,6 @@ Compile a string containing C source code.
 Add the given given symbol name / callback or pointer combination. See 
 example below for how to use this to call Perl from Tiny C code.
 
-It will accept a L<FFI::Raw::Callback> at a performance penalty. If 
-possible pass in the pointer to the C entry point instead.
-
 If you are using L<FFI::Platypus> you can use L<FFI::Platypus#cast>
 to get a pointer to a closure:
 
@@ -543,7 +511,7 @@ Undefine the given symbol.
 Set the output type.  This must be called before any compilation.
 
 Output formats may not be supported on your platform.  C<exe> is
-NOT supported on *BSD or OS X.
+NOT supported on *BSD or OS X.  It may NOT be supported on Linux.
 
 As a basic baseline at least C<memory> should be supported.
 
@@ -581,35 +549,6 @@ Output the generated code (either executable, object or DLL) to the
 given filename. The type of output is specified by the 
 L<set_output_type|/set_output_type> method.
 
-=head3 get_ffi_raw
-
-B<DEPRECATED>
-
- my $ffi = $tcc->get_ffi_raw($symbol_name, $return_type, @argument_types);
-
-Given the name of a function, return an L<FFI::Raw> instance that will 
-allow you to call it from Perl.
-
-This method is deprecated, and will be removed from a future version of 
-L<FFI::TinyCC>, but not before January 31, 2017.  It will issue a 
-warning if you try to use it.  Instead of this:
-
- my $function = $tcc->get_ffi_raw($name, FFI::void);
- $function->();
-
-Do this:
-
- use FFI::Raw;
- my $function = FFI::Raw->new_from_ptr($tcc->get_symbol($name), FFI::void);
- $function->();
-
-Or better yet, use L<FFI::Platypus> instead:
-
- use FFI::Platypus;
- my $ffi = FFI::Platypus->new;
- $ffi->attach([$tcc->get_symbol($name) => 'function'] => [] => 'void');
- function();
-
 =head1 EXAMPLES
 
 =head2 Calling Tiny C code from Perl
